summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmwarpedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmwarpedit.h')
-rw-r--r--kpovmodeler/pmwarpedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmwarpedit.h b/kpovmodeler/pmwarpedit.h
index fa12a358..653219b9 100644
--- a/kpovmodeler/pmwarpedit.h
+++ b/kpovmodeler/pmwarpedit.h
@@ -40,12 +40,13 @@ class TQLabel;
class PMWarpEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMWarpEdit with parent and name
*/
- PMWarpEdit( TQWidget* parent, const char* name = 0 );
+ PMWarpEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -40,12 +40,13 @@ class TQLabel;
public:
/**
- * Creates a PMWarpEdit with parent and name
+ * Creates a PMWarpEdit with tqparent and name
*/